%define name WALinuxAgent
%define version 2.2.46
%define unmangled_version 2.2.46
%define release 2
%define anolis_release .0.1 

%if 0%{?rhel} < 7
%global initsys sysV
%else
%global initsys systemd
%endif

Summary: Microsoft Azure Linux Agent
Name: %{name}
Version: %{version}
Release: %{release}%{anolis_release}%{?dist}
Source0: WALinuxAgent-2.2.46.tar.gz
#Add by Anolis
Patch0001: 0001-tests-common-osutil-test_factory.py.patch
#Add end
Patch0002: 0002-Remove-FIPS-setting-from-the-default-config.patch
# For bz#1822883 - [Azure][RHEL-7]Some parameter changes are not in waagent.conf
Patch3: wla-Update-Provisioning-options-1853.patch

License: ASL 2.0
Group: Development/Libraries
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot
Prefix: %{_prefix}
BuildArch: noarch
# Vendor: Yue Zhang, Stephen Zarkos, Eric Gable <walinuxagent@microsoft.com>
Url: https://github.com/Azure/WALinuxAgent

# rhel requirements

BuildRequires:  python2-devel
BuildRequires:  python-setuptools

Requires: util-linux
Requires: net-tools
Requires: openssh
Requires: openssh-server
Requires: openssl
Requires: parted
Requires: python-pyasn1

%if %{initsys} == systemd
Requires:       NetworkManager
%else
%if %{initsys} == sysV
Conflicts:      NetworkManager
%endif
%endif

%if %{initsys} == systemd
BuildRequires:   systemd
Requires(pre):  systemd
Requires(post):  systemd
Requires(preun): systemd
Requires(postun): systemd
%else
%if %{initsys} == sysv
Requires(post):  chkconfig
Requires(preun): chkconfig
Requires(preun): initscripts
Requires(postun): initscripts
%endif
%endif

%description
The Azure Linux Agent supports the provisioning and running of Linux
VMs in the Azure cloud. This package should be installed on Linux disk
images that are built to run in the Azure environment.


%prep
%setup -n %{name}-%{unmangled_version} -n %{name}-%{unmangled_version}
#Add by Anolis
%patch0001 -p1
#Add end
%patch0002 -p1
%patch3 -p1

%build
python setup.py build

%install
python setup.py install --single-version-externally-managed -O1 --root=$RPM_BUILD_ROOT --record=INSTALLED_FILES

%clean
rm -rf $RPM_BUILD_ROOT

%post
%if %{initsys} == systemd
%systemd_post waagent.service
%else
%if %{initsys} == sysV
/sbin/chkconfig --add waagent
%endif
%endif

%preun
%if %{initsys} == systemd
%systemd_preun waagent.service
%else
%if %{initsys} == sysV
if [ $1 = 0 ]; then
        /sbin/service waagent stop >/dev/null 2>&1
        /sbin/chkconfig --del waagent
fi
%endif
%endif

%postun
%if %{initsys} == systemd
%systemd_postun_with_restart waagent.service
%else
%if %{initsys} == sysV
if [ "$1" -ge "1" ]; then
        /sbin/service waagent restart >/dev/null 2>&1 || :
fi
%endif
%endif

%files
%defattr(-,root,root)
%{python_sitelib}/*
%config(noreplace) %{_sysconfdir}/waagent.conf
%{_sysconfdir}/logrotate.d/waagent.logrotate
%{_sbindir}/waagent
%{_sbindir}/waagent2.0
%{_unitdir}/waagent.service
/etc/udev/rules.d/66-azure-storage.rules
/etc/udev/rules.d/99-azure-product-uuid.rules
/etc/logrotate.d/waagent-extn.logrotate

%changelog
* Fri Dec 24 2021 qingxiyingyue <lichaod@uniontech.com> -2.2.46-2.0.1
- 0001-tests-common-osutil-test_factory.py.patch
- Add distro support for anolisos 

* Wed Jun 03 2020 Miroslav Rezanina <mrezanin@redhat.com> - 2.2.46-2
- wla-Update-Provisioning-options-1853.patch [bz#1822883]
- Resolves: bz#1822883
  ([Azure][RHEL-7]Some parameter changes are not in waagent.conf)

* Mon Mar 16 2020 Miroslav Rezanina <mrezanin@redhat.com> - 2.2.46-1
- Rebase to 2.2.26 [bz#1794682]
- Resolves: bz#1794682
  ([Azure][RHEL-7]Rebase WALinuxAgent to 2.2.46)

* Wed Feb 19 2020 Miroslav Rezanina <mrezanin@redhat.com> - 2.2.38-2.el7
- wla-Add-support-for-Gen2-VM-resource-disks-1654.patch [bz#1714167]
- Resolves: bz#1714167
  ([Azure][WALA] Cannot find temporary disk device in Gen2 VM)

* Fri Jun 28 2019 Miroslav Rezanina <mrezanin@redhat.com> - 2.2.38-1.el7
- Rebase to 2.2.38 [bz#1721727]
- Resolves: bz#1721727
  ([Azure]walinuxagent 2.2.38 packaging request)

* Tue Dec 11 2018 Miroslav Rezanina <mrezanin@redhat.com> - 2.2.32-1.el7
- Rebase to 2.2.32 [bz#1639496]
- Resolves: bz#1639496
  (walinuxagent 2.2.32 packaging request)

* Wed Aug 29 2018 Miroslav Rezanina <mrezanin@redhat.com> - 2.2.26-2.el7
- Fixing unit file location

* Wed Jul 25 2018 Miroslav Rezanina <mrezanin@redhat.com> - 2.2.26-1.el7
- Rebase to 2.2.26 [bz#1562222]
  (Rebase WALinuxAgent in RHEL-7.6)

* Thu May 03 2018 Miroslav Rezanina <mrezanin@redhat.com> - 2.2.18-2.el7
- wa-Add-show-configuration-option.patch [bz#1508340]
- Resolves: bz#1508340
  ([WALA] WALA usage prompt lack of " waagent -show-configuration")

* Tue Oct 10 2017 Miroslav Rezanina <mrezanin@redhat.com> - 2.2.18-1.el7
- Rebase to 2.2.18 [bz#1491873]
- Resolves: bz#1491873
  ([WALA]Request to package WALA 2.2.18 into RHEL 7 Repo)


* Tue Jul 04 2017 Miroslav Rezanina <mrezanin@redhat.com> - 2.2.14-1.el7
- Rebase to 2.2.14 [bz#1451172]
- wla-Remove-FIPS-setting-from-the-default-config.patch [bz#1467553]
- Resolves: bz#1451172
  ([WALA] Request to package WALA 2.2.14 into RHEL 7 Repo)
- Resolves: bz#1467553
  ([WALA] Remove FIPS from default config in WALA-2.2.14)

* Wed Apr 26 2017 Miroslav Rezanina <mrezanin@redhat.com> - 2.2.10-1.el7
- Rebase to 2.2.10 [bz#1443425]
- Resolves: bz#1443425
  ([WALA]Request to package WALA 2.2.10 into RHEL 7 Repo)

* Wed Apr 19 2017 Miroslav Rezanina <mrezanin@redhat.com> - 2.2.4-2.el7
- Enable AutoUpdate by default [bz#1434933]
- Resolves: bz#1434933
  ([WALA][RHEL-7] Enable AutoUpdate by default)

* Wed Mar 01 2017 Miroslav Rezanina <mrezanin@redhat.com> - 2.2.4-1.el7
- Rebase to 2.2.4 [bz#1419201]
- resolves: bz#1419201
  WALA 2.2.4

* Mon Jan 16 2017 Miroslav Rezanina <mrezanin@redhat.com> - 2.2.0-4.el7
- agent-RHEL-7-hostname-533.patch [bz#1413674]
- agent-fix-for-hostnamectl-534.patch [bz#1413674]
- Resolves: bz#1413674
  ([WALA] Fail to send hostname to DHCP server during provisioning)

* Fri Sep 30 2016 Dave Anderson <anderson@redhat.com> - 2.2.0-1
- Update to v2.2.0
  Resolves: rhbz#1360492

* Wed Sep 21 2016 Dave Anderson <anderson@redhat.com> - 2.1.5-2
- Several QE updates to this file
  Resolves: rhbz#1360492

* Tue Sep 13 2016 Dave Anderson <anderson@redhat.com> - 2.1.5-1
- Update to v2.1.5
  Resolves: rhbz#1360492

* Thu Jan 14 2016 Dave Anderson <anderson@redhat.com> - 2.0.16-1
- Update to 2.0.16
  Resolves: rhbz#1296360

* Mon Jun 01 2015 Dave Anderson <anderson@redhat.com> - 2.0.13-1
- Update to upstream 2.0.13 package.
- Remove global commit md5sum and fix Source0 to point to correct location.
- Fix setup to deal with "WALinuxAgent-WALinuxAgent" naming scheme
- Added files reference for /udev/rules.d/99-azure-product-uuid.rules

* Thu May 07 2015 Dave Anderson <anderson@redhat.com> - 2.0.11-3
- Remove Requires: ntfsprogs for RHEL7

* Sat Jan 10 2015 Scott K Logan <logans@cottsay.net> - 2.0.11-2
- Use systemd for rhel7
- Own logrotate.d
- Fix python2-devel dep

* Sat Dec 20 2014 Scott K Logan <logans@cottsay.net> - 2.0.11-1
- Initial package
